@@ -21,6 +21,8 @@ class WLANInterface(AbstractInterface):
   wifi_icd2_iface = 'com.nokia.icd2'
   wifi_icd2_state_signal = 'state_sig'
   wifi_icd2_statistics_signal = 'statistics_sig'
+  wifi_icdui_path = '/com/nokia/icd_ui'
+  wifi_icdui_iface = 'com.nokia.icd_ui'
 
   def pre_init(self):
     self.has_be = get_shell_command_output('ls /lib/modules/$(uname -r) | grep -m 1 wl1251') != ''
@@ -43,10 +45,18 @@ class WLANInterface(AbstractInterface):
     }
     if self.has_be:
       self.state['modes'] = ('wlan-stock', 'wlan-bleeding-edge')
-    self.interfaces = {'ICD': [self.wifi_icd2_iface, self.wifi_icd2_path, self.wifi_icd2_iface, '/usr/sbin/icd2', False]}
+    self.interfaces = {
+      'ICD': [self.wifi_icd2_iface, self.wifi_icd2_path, self.wifi_icd2_iface, '/usr/sbin/icd2', False],
+      'ICD_UI': [self.wifi_icdui_iface, self.wifi_icdui_path, self.wifi_icdui_iface, '/usr/sbin/icd2', False]
+    }
 
   def process_signal_on(self, *args, **kwargs):
-    if args[0] == '/org/freedesktop/Hal/devices/platform_wl12xx': return int(kwargs['member'] == 'DeviceAdded'), 0, None
+    if args[0] == '/org/freedesktop/Hal/devices/platform_wl12xx':
+      state = int(kwargs['member'] == 'DeviceAdded')
+      if state and self.get_config_value('show-connection-dialog'):
+        #self.scan_request()
+        gobject.idle_add(self.show_connection_dialog)
+      return state, 0, None
     else: return None, None, None
 
   def process_signal_connected(self, *args):
@@ -92,6 +102,9 @@ class WLANInterface(AbstractInterface):
 #    self.scan_request()
     self.switched()
 
+  def show_connection_dialog(self):
+    self.get_interface('ICD_UI').show_conn_dlg(False)
+
   def scan_request(self):
     try: self.get_interface('ICD').scan_req(dbus.UInt32(0), dbus.Array([], signature='s'))
     except: self.reinit_interface('ICD')
