@@ -39,7 +39,8 @@ class AISLocale(Locale):
       'settings/wlan/show-state-dialog': 'WLAN: dialog on click',
       'settings/wlan/enable-on-startup': 'WLAN: enable on startup',
       'settings/wlan/mode-on-startup': 'WLAN: enabled mode on startup',
-      'settings/wlan/show-popups': 'WLAN: show popups'
+      'settings/wlan/show-popups': 'WLAN: show popups',
+      'settings/wlan/show-connection-dialog': 'WLAN: show connection dialog'
     }
 
 __locale_singleton = AISLocale()
